import React from 'react';
import { Box, Grid, ResponsiveContext, Heading } from 'grommet';

import { Album } from './Album';
import { Artists, Albums } from '../interfaces';
import { Other } from './Other';
import placeholder from '../assets/placeholder-music.jpg';

export const Results = ({
	artists,
	handleClick,
}: {
	artists: Artists;
	handleClick: (name: string) => void;
}) => {
	const { name: selectedName, image, albums } = artists[0];
	const otherArtists = artists.slice(1, artists.length);
	let selectedAlbums: Albums = [];
	let selectedImage: string = image;

	// Load placeholder image if none provided
	if (!image) {
		selectedImage = placeholder;
	}

	// Remove duplicate albums based on `name`
	// Might need to refine this according to the data quality
	const uniqueAlbums = new Set();
	albums.forEach((album) => {
		if (!uniqueAlbums.has(album.name)) {
			uniqueAlbums.add(album.name);
			selectedAlbums.push(album);
		}
	});

	return (
		<Grid
			as='section'
			rows={['fit', 'fit']}
			columns={['fit', 'fit']}
			gap='large'
			areas={[
				['title', 'title'],
				['artist-other', 'artist-other'],
				['disco-title', 'disco-title'],
				['discography', 'discography'],
			]}
			pad='xlarge'
		>
			<Heading
				level='1'
				gridArea='title'
				size='medium'
				margin={{ vertical: 'none' }}
			>
				{selectedName}
			</Heading>
			<Box
				gridArea='artist-other'
				direction='row-responsive'
				responsive
				gap='large'
			>
				<Box width={{ min: '300px', max: '300px' }}>
					<Box
						round='full'
						background={{
							repeat: 'no-repeat',
							size: 'cover',
							image: `url(${selectedImage})`,
						}}
						height='300px'
						width='300px'
					/>
				</Box>
				<Box justify='center'>
					<Heading
						level='2'
						margin={{ vertical: 'none' }}
						size='small'
					>
						Other results
					</Heading>
					<Box
						direction='row-reverse'
						justify='end'
						wrap
						gap='medium'
						width={{ min: '332px' }}
					>
						{otherArtists.map((artist) => (
							<Other
								key={artist.id}
								image={artist.image}
								name={artist.name}
								handleClick={handleClick}
							/>
						))}
					</Box>
				</Box>
			</Box>
			<Heading
				level='2'
				gridArea='disco-title'
				size='medium'
				margin={{ bottom: 'none' }}
			>
				Discography
			</Heading>
			<ResponsiveContext.Consumer>
				{(size) => (
					<Grid
						gridArea='discography'
						align='start'
						columns={{ count: 'fill', size: '260px' }}
						gap='large'
					>
						{selectedAlbums.map((album) => (
							<Album
								key={album.id}
								image={album.image}
								name={album.name}
							/>
						))}
					</Grid>
				)}
			</ResponsiveContext.Consumer>
		</Grid>
	);
};
